@@ -246,10 +246,16 @@ test_that("scale_colour_multi handles discrete guides", {
 # Warnings ----------------------------------------------------------------
 
 test_that("scale_colour_multi throws error when guide inappropriate", {
-  g <- expect_error(base + scale_colour_multi(aesthetics = c("fill1", "fill2", "fill3"),
-                                            colours = list(c("white", "red"),
-                                                           c("black", "blue"),
-                                                           c("grey50", "green")),
-                                            guide = "nonsense"), regexp = "I haven't programmed this path yet")
+  expect_snapshot_error(
+    base + scale_colour_multi(
+      aesthetics = c("fill1", "fill2", "fill3"),
+      colours = list(
+        c("white", "red"),
+        c("black", "blue"),
+        c("grey50", "green")
+      ),
+      guide = "nonsense"
+    )
+  )
 })
 
